@@ -1,20 +1,20 @@
 from django.contrib.auth.decorators import login_required
 from django.utils.decorators import method_decorator
 from django.views.generic import ListView
+from rest_framework import mixins, permissions
 from rest_framework.viewsets import GenericViewSet
 
 from djgentelella.models import Notification
-from djgentelella.notification.serializer import NotificationSerializer, NotificationPagination, \
+from djgentelella.notification.serializer import NotificationSerializer, \
+    NotificationPagination, \
     NotificationSerializerUpdate
 
-from rest_framework import mixins, permissions
 
-
-class NotificacionAPIView( mixins.RetrieveModelMixin,
-                           mixins.UpdateModelMixin,
-                           mixins.DestroyModelMixin,
-                           mixins.ListModelMixin,
-                           GenericViewSet):
+class NotificacionAPIView(mixins.RetrieveModelMixin,
+                          mixins.UpdateModelMixin,
+                          mixins.DestroyModelMixin,
+                          mixins.ListModelMixin,
+                          GenericViewSet):
     queryset = Notification.objects.all()
     serializer_class = NotificationSerializer
     pagination_class = NotificationPagination
@@ -38,5 +38,6 @@ class NotificationList(ListView):
 
     def get_queryset(self):
         queryset = super(NotificationList, self).get_queryset()
-        queryset = queryset.filter(user=self.request.user).order_by('state', 'creation_date')
-        return queryset
\ No newline at end of file
+        queryset = queryset.filter(user=self.request.user).order_by('state',
+                                                                    'creation_date')
+        return queryset
